AAListItem class
Constructors
- AAListItem({required String title, String? subtitle, String? imageUrl, dynamic onPress(dynamic complete(), AAListItem self)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageUrl → String?
-
final
- onPress → dynamic Function(dynamic complete(), AAListItem self)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
final
- title → String
-
final
- uniqueId → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited